@@ -20,6 +20,8 @@ export const actions = {
 	COUNT_BOOKMARKS: 'COUNT_BOOKMARKS',
 	COUNT_UNAVAILABLE: 'COUNT_UNAVAILABLE',
 	COUNT_ARCHIVED: 'COUNT_ARCHIVED',
+	COUNT_DUPLICATED: 'COUNT_DUPLICATED',
+
 	CREATE_BOOKMARK: 'CREATE_BOOKMARK',
 	FIND_BOOKMARK: 'FIND_BOOKMARK',
 	LOAD_BOOKMARK: 'LOAD_BOOKMARK',
@@ -57,6 +59,7 @@ export const actions = {
 	FILTER_BY_UNTAGGED: 'FILTER_BY_UNTAGGED',
 	FILTER_BY_UNAVAILABLE: 'FILTER_BY_UNAVAILABLE',
 	FILTER_BY_ARCHIVED: 'FILTER_BY_ARCHIVED',
+	FILTER_BY_DUPLICATED: 'FILTER_BY_DUPLICATED',
 	FILTER_BY_TAGS: 'FILTER_BY_TAGS',
 	FILTER_BY_FOLDER: 'FILTER_BY_FOLDER',
 	FILTER_BY_SHARED_FOLDERS: 'FILTER_BY_SHARED_FOLDERS',
@@ -133,6 +136,28 @@ export default {
 			throw err
 		}
 	},
+	async [actions.COUNT_DUPLICATED]({ commit, dispatch, state }) {
+		try {
+			const response = await axios.get(url(state, '/bookmark/duplicated'))
+			const {
+				data: { item: count, data, status },
+			} = response
+			if (status !== 'success') {
+				throw new Error(data)
+			}
+			commit(mutations.SET_DUPLICATED_COUNT, count)
+		} catch (err) {
+			console.error(err)
+			commit(
+				mutations.SET_ERROR,
+				AppGlobal.methods.t(
+					'bookmarks',
+					'Failed to count duplicated bookmarks'
+				)
+			)
+			throw err
+		}
+	},
 	async [actions.COUNT_BOOKMARKS]({ commit, dispatch, state }, folderId) {
 		try {
 			const response = await axios.get(
@@ -940,7 +965,7 @@ export default {
 		return dispatch(actions.FETCH_PAGE)
 	},
 	[actions.FILTER_BY_SEARCH]({ dispatch, commit }, search) {
-		commit(mutations.SET_QUERY, { search: search.split(' ') })
+		commit(mutations.SET_QUERY, { search: search.split(' '), conjunction: 'and' })
 		return dispatch(actions.FETCH_PAGE)
 	},
 	[actions.FILTER_BY_TAGS]({ dispatch, commit }, tags) {
@@ -959,6 +984,10 @@ export default {
 		commit(mutations.SET_QUERY, { archived: true })
 		return dispatch(actions.FETCH_PAGE)
 	},
+	[actions.FILTER_BY_DUPLICATED]({ dispatch, commit }) {
+		commit(mutations.SET_QUERY, { duplicated: true })
+		return dispatch(actions.FETCH_PAGE)
+	},
 	[actions.FILTER_BY_FOLDER]({ dispatch, commit, state }, folder) {
 		commit(mutations.SET_QUERY, { folder })
 		if (state.settings.sorting === 'index') {
@@ -1108,7 +1137,7 @@ export default {
 	},
 	[actions.LOAD_SETTINGS]({ commit, dispatch, state }) {
 		return Promise.all(
-			['sorting', 'viewMode', 'archivePath', 'limit'].map(key =>
+			['sorting', 'viewMode', 'archivePath', 'backupPath', 'limit'].map(key =>
 				dispatch(actions.LOAD_SETTING, key)
 			)
 		)
